{% extends "package/base.html" %} {% block subtitle %}{{ pkg_dict.name }} {{ g.template_title_delimiter }} Changes {{ g.template_title_delimiter }} {{ super() }}{% endblock %} {% block breadcrumb_content_selected %}{% endblock %} {% block breadcrumb_content %} {{ super() }}
- {% link_for _('Changes'), named_route=dataset_type ~ '.activity', id=pkg_dict.name %}
- {% link_for activity_diffs[0].activities[1].id|truncate(30), named_route=dataset_type ~ '.changes', id=activity_diffs[0].activities[1].id %}
{% endblock %} {% block primary %}
{% block package_changes_header %}

# {{ _('Changes') }}

{% endblock %} {% set select_list1 = h.activity_list_select(pkg_activity_list, activity_diffs[-1].activities[0].id) %} {% set select_list2 = h.activity_list_select(pkg_activity_list, activity_diffs[0].activities[1].id) %} View changes from
to
{# iterate through the list of activity diffs #}

{% for i in range(activity_diffs|length) %} {% snippet "package/snippets/change_item.html", activity_diff=activity_diffs[i], pkg_dict=pkg_dict %} {# TODO: display metadata for more than most recent change #} {% if i == 0 %} {# button to show JSON metadata diff for the most recent change - not shown by default #}
{% block package_changes_diff %}

                  {{ activity_diffs[0]['diff']|safe }}

{% endblock %}
{% endif %}

{% endfor %}
{% endblock %} {% block secondary %}{% endblock %}